==> community-themes_0.22.1.tar.gz: community-themes-0.22.1/setup.py <==
from distutils.core import setup
from DistUtilsExtra.command import *
import glob

import os
import re

# look/set what version we have
changelog = "debian/changelog"
version = "0.1"
if os.path.exists(changelog):
    head=open(changelog).readline()
    match = re.compile(".*\((.*)\).*").match(head)
    if match:
        version = match.group(1)

setup(
    name = 'community-themes',
    version = version,
    data_files=[('share/themes/Impression/metacity-1',
                 glob.glob('Impression/metacity-1/*')),
                ('share/themes/Impression/gtk-2.0',
                 glob.glob('Impression/gtk-2.0/*')),
                ('share/themes/Night-Impression/metacity-1',
                 glob.glob('Night-Impression/metacity-1/*')),
                ('share/themes/Night-Impression/gtk-2.0',
                 glob.glob('Night-Impression/gtk-2.0/*')),
                ('share/themes/Kin/metacity-1',
                 glob.glob('Kin/metacity-1/*')),
                ('share/themes/Kin/gtk-2.0',
                 glob.glob('Kin/gtk-2.0/*')),
                ('share/themes/Turrican/metacity-1',
                 glob.glob('Turrican/metacity-1/*')),
                ('share/themes/Turrican/gtk-2.0',
                 glob.glob('Turrican/gtk-2.0/*')),
                ('share/themes/Hanso/metacity-1',
                 glob.glob('Hanso/metacity-1/*')),
                ('share/themes/Hanso/gtk-2.0',
                 glob.glob('Hanso/gtk-2.0/*.png')),
                ('share/themes/Hanso/gtk-2.0',
                 glob.glob('Hanso/gtk-2.0/*rc')),
                ('share/themes/Hanso/gtk-2.0/Handles',
                 glob.glob('Hanso/gtk-2.0/Handles/*')),
		('share/themes/Hanso/gtk-2.0/Lines',
                 glob.glob('Hanso/gtk-2.0/Lines/*')),
		('share/themes/Hanso/gtk-2.0/Panel',
                 glob.glob('Hanso/gtk-2.0/Panel/*')),
		('share/themes/Hanso/gtk-2.0/Others',
                 glob.glob('Hanso/gtk-2.0/Others/*')),				
		('share/themes/Homosapien/metacity-1',
                 glob.glob('Homosapien/metacity-1/*')),
                ('share/themes/Homosapien/gtk-2.0',
                 glob.glob('Homosapien/gtk-2.0/*.png')),
                ('share/themes/Homosapien/gtk-2.0',
                 glob.glob('Homosapien/gtk-2.0/*rc')),
		('share/themes/Homosapien/gtk-2.0/Lines',
                 glob.glob('Homosapien/gtk-2.0/Lines/*')),
		('share/themes/Homosapien/gtk-2.0/Panel',
                 glob.glob('Homosapien/gtk-2.0/Panel/*')),
		('share/themes/Homosapien/gtk-2.0/Others',
                 glob.glob('Homosapien/gtk-2.0/Others/*')),
		('share/themes/Sorbet/metacity-1',
                 glob.glob('Sorbet/metacity-1/*')),
                ('share/themes/Sorbet/gtk-2.0',
                 glob.glob('Sorbet/gtk-2.0/*.png')),
                ('share/themes/Sorbet/gtk-2.0',
                 glob.glob('Sorbet/gtk-2.0/*rc')),
		('share/themes/Sorbet/gtk-2.0/Lines',
                 glob.glob('Sorbet/gtk-2.0/Lines/*')),
		('share/themes/Sorbet/gtk-2.0/Panels',
                 glob.glob('Sorbet/gtk-2.0/Panels/*')),
		('share/themes/Sorbet/gtk-2.0/Others',
                 glob.glob('Sorbet/gtk-2.0/Others/*')),
		('share/themes/Wasp-Murrine/metacity-1',
                 glob.glob('Wasp-Murrine/metacity-1/*')),
                ('share/themes/Wasp-Murrine/gtk-2.0',
                 glob.glob('Wasp-Murrine/gtk-2.0/*rc')),
                ('share/themes/Wasp-Murrine/xfwm4',
                 glob.glob('Wasp-Murrine/xfwm4/*')),
                ('share/themes/Wasp-Murrine/gtk-2.0/apps',
                 glob.glob('Wasp-Murrine/gtk-2.0/apps/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/lock-dialog',
                 glob.glob('Wasp-Murrine/gtk-2.0/lock-dialog/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/panels',
                 glob.glob('Wasp-Murrine/gtk-2.0/panels/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/widget',
                 glob.glob('Wasp-Murrine/gtk-2.0/widget/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/xfce',
                 glob.glob('Wasp-Murrine/gtk-2.0/xfce/*')),
               ],
    cmdclass = { "build" : build_extra.build_extra,
                 "build_i18n" :  build_i18n.build_i18n }
)

==> community-themes_0.23.1.tar.gz: community-themes-0.23.1/setup.py <==
from distutils.core import setup
from DistUtilsExtra.command import *
import glob

import os
import re

# look/set what version we have
changelog = "debian/changelog"
version = "0.1"
if os.path.exists(changelog):
    head=open(changelog).readline()
    match = re.compile(".*\((.*)\).*").match(head)
    if match:
        version = match.group(1)

setup(
    name = 'community-themes',
    version = version,
    data_files=[('share/themes/Impression/metacity-1',
                 glob.glob('Impression/metacity-1/*')),
                ('share/themes/Impression/gtk-2.0',
                 glob.glob('Impression/gtk-2.0/*rc')),
                ('share/themes/Impression/gtk-2.0/images',
                 glob.glob('Impression/gtk-2.0/images/*.*')),
                ('share/themes/Impression/gtk-2.0/images/panel',
                 glob.glob('Impression/gtk-2.0/images/panel/*')),
                ('share/themes/Impression/gtk-2.0/images/nautilus',
                 glob.glob('Impression/gtk-2.0/images/nautilus/*')),
                ('share/themes/Night-Impression/metacity-1',
                 glob.glob('Night-Impression/metacity-1/*')),
                ('share/themes/Night-Impression/gtk-2.0',
                 glob.glob('Night-Impression/gtk-2.0/*rc')),
                ('share/themes/Night-Impression/gtk-2.0/images',
                 glob.glob('Night-Impression/gtk-2.0/images/*.*')),
                ('share/themes/Night-Impression/gtk-2.0/images/panel',
                 glob.glob('Night-Impression/gtk-2.0/images/panel/*')),
                ('share/themes/Night-Impression/gtk-2.0/images/nautilus',
                 glob.glob('Night-Impression/gtk-2.0/images/nautilus/*')),
                ('share/themes/Kin/metacity-1',
                 glob.glob('Kin/metacity-1/*')),
                ('share/themes/Kin/gtk-2.0',
                 glob.glob('Kin/gtk-2.0/*')),
                ('share/themes/Turrican/metacity-1',
                 glob.glob('Turrican/metacity-1/*')),
                ('share/themes/Turrican/gtk-2.0',
                 glob.glob('Turrican/gtk-2.0/*')),
                ('share/themes/Hanso/metacity-1',
                 glob.glob('Hanso/metacity-1/*')),
                ('share/themes/Hanso/gtk-2.0',
                 glob.glob('Hanso/gtk-2.0/*.png')),
                ('share/themes/Hanso/gtk-2.0',
                 glob.glob('Hanso/gtk-2.0/*rc')),
                ('share/themes/Hanso/gtk-2.0/Handles',
                 glob.glob('Hanso/gtk-2.0/Handles/*')),
		('share/themes/Hanso/gtk-2.0/Lines',
                 glob.glob('Hanso/gtk-2.0/Lines/*')),
		('share/themes/Hanso/gtk-2.0/Panel',
                 glob.glob('Hanso/gtk-2.0/Panel/*')),
		('share/themes/Hanso/gtk-2.0/Others',
                 glob.glob('Hanso/gtk-2.0/Others/*')),				
		('share/themes/Homosapien/metacity-1',
                 glob.glob('Homosapien/metacity-1/*')),
                ('share/themes/Homosapien/gtk-2.0',
                 glob.glob('Homosapien/gtk-2.0/*.png')),
                ('share/themes/Homosapien/gtk-2.0',
                 glob.glob('Homosapien/gtk-2.0/*rc')),
		('share/themes/Homosapien/gtk-2.0/Lines',
                 glob.glob('Homosapien/gtk-2.0/Lines/*')),
		('share/themes/Homosapien/gtk-2.0/Panel',
                 glob.glob('Homosapien/gtk-2.0/Panel/*')),
		('share/themes/Homosapien/gtk-2.0/Others',
                 glob.glob('Homosapien/gtk-2.0/Others/*')),
		('share/themes/Sorbet/metacity-1',
                 glob.glob('Sorbet/metacity-1/*')),
                ('share/themes/Sorbet/gtk-2.0',
                 glob.glob('Sorbet/gtk-2.0/*.png')),
                ('share/themes/Sorbet/gtk-2.0',
                 glob.glob('Sorbet/gtk-2.0/*rc')),
		('share/themes/Sorbet/gtk-2.0/Lines',
                 glob.glob('Sorbet/gtk-2.0/Lines/*')),
		('share/themes/Sorbet/gtk-2.0/Panels',
                 glob.glob('Sorbet/gtk-2.0/Panels/*')),
		('share/themes/Sorbet/gtk-2.0/Others',
                 glob.glob('Sorbet/gtk-2.0/Others/*')),
		('share/themes/Wasp-Murrine/metacity-1',
                 glob.glob('Wasp-Murrine/metacity-1/*')),
                ('share/themes/Wasp-Murrine/gtk-2.0',
                 glob.glob('Wasp-Murrine/gtk-2.0/*rc')),
                ('share/themes/Wasp-Murrine/xfwm4',
                 glob.glob('Wasp-Murrine/xfwm4/*')),
                ('share/themes/Wasp-Murrine/gtk-2.0/apps',
                 glob.glob('Wasp-Murrine/gtk-2.0/apps/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/lock-dialog',
                 glob.glob('Wasp-Murrine/gtk-2.0/lock-dialog/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/panels',
                 glob.glob('Wasp-Murrine/gtk-2.0/panels/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/widget',
                 glob.glob('Wasp-Murrine/gtk-2.0/widget/*')),
		('share/themes/Wasp-Murrine/gtk-2.0/xfce',
                 glob.glob('Wasp-Murrine/gtk-2.0/xfce/*')),
               ],
    cmdclass = { "build" : build_extra.build_extra,
                 "build_i18n" :  build_i18n.build_i18n }
)
